/*
Created			21/10/2011
Modified			02/11/2011
Project			Manteniment			
Author			David Puchercs Ferrer
Version			1.0
Database			Oracle 10g 
*/


-- Create Tables section


Create table "aparell" (
	"id_aparell" Number NOT NULL ,
	"id_tipus_aparell" Number NOT NULL ,
	"id_centre_treball" Number NOT NULL ,
	"marca" NVarchar2(50) NOT NULL ,
	"model" NVarchar2(50) NOT NULL ,
	"data_compra" Date NOT NULL ,
	"data_inici_garantia" Date,
	"data_fi_garantia" Date,
	"numero_serie" NVarchar2(50),
	"observacions" NVarchar2(200),
	"data_baixa" Date,
primary key ("id_aparell") 
) 
/

Create table "manteniment_preventiu" (
	"id_mant_prev" Number NOT NULL ,
	"id_aparell" Number NOT NULL ,
	"data_manteniment" Date NOT NULL ,
	"observacions" NVarchar2(200),
	"id_tecnic" Number,
primary key ("id_mant_prev") 
) 
/

Create table "requeriment_manteniment" (
	"id_req_mant" Number NOT NULL ,
	"periocitat" NVarchar2(50) NOT NULL ,
	"descripcio" NVarchar2(200),
	"data_inici" Date,
	"data_fi" Date,
	"id_tipus_aparell" Number NOT NULL ,
primary key ("id_req_mant") 
) 
/

Create table "empleat" (
	"id_empleat" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
	"primer_cognom" NVarchar2(50) NOT NULL ,
	"segon_cognom" NVarchar2(50) NOT NULL ,
	"NIF" Varchar2 (9) NOT NULL ,
	"telefon" Varchar2 (20),
	"id_adre" Number NOT NULL ,
primary key ("id_empleat") 
) 
/

Create table "empresa_manteniment" (
	"id_empr_mant" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
	"NIF" Varchar2 (9) NOT NULL ,
	"telefon" Varchar2 (20),
	"id_adre" Number NOT NULL ,
primary key ("id_empr_mant") 
) 
/

Create table "manteniment_correctiu" (
	"id_mant_correct" Number NOT NULL ,
	"prioritat" NVarchar2(50),
	"data_incidencia" Date NOT NULL ,
	"data_manteniment" Date,
	"observacions" Varchar2 (200),
	"id_tecnic" Number,
	"id_aparell" Number NOT NULL ,
	"id_empr_mant" Number NOT NULL ,
	"id_empleat" Number NOT NULL ,
primary key ("id_mant_correct") 
) 
/

Create table "tipus_aparell" (
	"id_tipus_aparell" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
	"descripcio" NVarchar2(200),
primary key ("id_tipus_aparell") 
) 
/

Create table "contracte" (
	"id_contracte" Number NOT NULL ,
	"data_inici" Date NOT NULL ,
	"data_fi" Date,
	"id_aparell" Number NOT NULL ,
	"id_empr_mant" Number NOT NULL ,
primary key ("id_contracte") 
) 
/

Create table "tecnic" (
	"id_tecnic" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
	"primer_cognom" NVarchar2(50) NOT NULL ,
	"segon_cognom" NVarchar2(50) NOT NULL ,
	"NIF" Varchar2 (9) NOT NULL ,
	"telefon" Varchar2 (20),
primary key ("id_tecnic") 
) 
/

Create table "centre_treball" (
	"id_centre_treball" Number NOT NULL ,
	"nom" Varchar2 (50) NOT NULL ,
	"telefon" Varchar2 (20),
	"correu_electronic" Varchar2 (50),
	"id_adre" Number NOT NULL ,
primary key ("id_centre_treball") 
) 
/

Create table "adrea" (
	"id_adre" Number NOT NULL ,
	"nom_via" NVarchar2(50) NOT NULL ,
	"numero" Varchar2 (8) NOT NULL ,
	"codi_postal" Varchar2 (5) NOT NULL ,
	"pis" Varchar2 (5),
	"porta" Varchar2 (5),
	"id_pobl" Number NOT NULL ,
	"id_tipus_via" Number NOT NULL ,
primary key ("id_adre") 
) 
/

Create table "tipus_via" (
	"id_tipus_via" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
primary key ("id_tipus_via") 
) 
/

Create table "poblacio" (
	"id_pobl" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
	"id_prov" Number NOT NULL ,
primary key ("id_pobl") 
) 
/

Create table "provincia" (
	"id_prov" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
	"id_pais" Number NOT NULL ,
primary key ("id_prov") 
) 
/

Create table "pais" (
	"id_pais" Number NOT NULL ,
	"nom" NVarchar2(50) NOT NULL ,
primary key ("id_pais") 
) 
/



-- Create Foreign keys section

Alter table "manteniment_preventiu" add  foreign key ("id_aparell") references "aparell" ("id_aparell") 
/

Alter table "contracte" add  foreign key ("id_aparell") references "aparell" ("id_aparell") 
/

Alter table "manteniment_correctiu" add  foreign key ("id_aparell") references "aparell" ("id_aparell") 
/

Alter table "manteniment_correctiu" add  foreign key ("id_empleat") references "empleat" ("id_empleat") 
/

Alter table "contracte" add  foreign key ("id_empr_mant") references "empresa_manteniment" ("id_empr_mant") 
/

Alter table "manteniment_correctiu" add  foreign key ("id_empr_mant") references "empresa_manteniment" ("id_empr_mant") 
/

Alter table "aparell" add  foreign key ("id_tipus_aparell") references "tipus_aparell" ("id_tipus_aparell") 
/

Alter table "requeriment_manteniment" add  foreign key ("id_tipus_aparell") references "tipus_aparell" ("id_tipus_aparell") 
/

Alter table "manteniment_correctiu" add  foreign key ("id_tecnic") references "tecnic" ("id_tecnic") 
/

Alter table "manteniment_preventiu" add  foreign key ("id_tecnic") references "tecnic" ("id_tecnic") 
/

Alter table "aparell" add  foreign key ("id_centre_treball") references "centre_treball" ("id_centre_treball") 
/

Alter table "centre_treball" add  foreign key ("id_adre") references "adrea" ("id_adre") 
/

Alter table "empleat" add  foreign key ("id_adre") references "adrea" ("id_adre") 
/

Alter table "empresa_manteniment" add  foreign key ("id_adre") references "adrea" ("id_adre") 
/

Alter table "adrea" add  foreign key ("id_tipus_via") references "tipus_via" ("id_tipus_via") 
/

Alter table "adrea" add  foreign key ("id_pobl") references "poblacio" ("id_pobl") 
/

Alter table "poblacio" add  foreign key ("id_prov") references "provincia" ("id_prov") 
/

Alter table "provincia" add  foreign key ("id_pais") references "pais" ("id_pais") 
/

