-- font http://www.oracle-base.com/articles/misc/SchemaOwnersAndApplicationUsers.php
-- font http://www.techonthenet.com/oracle/grant_revoke.php
-- executar-ho com usuari administrador

--creaci usuari accs read-write

CREATE USER app_user_rw IDENTIFIED BY app_user_rw
  DEFAULT TABLESPACE users
  TEMPORARY TABLESPACE temp
  ACCOUNT UNLOCK;

GRANT CONNECT TO app_user_rw;


--creaci usuari accs read-only

CREATE USER app_user_ro IDENTIFIED BY app_user_ro
  DEFAULT TABLESPACE users
  TEMPORARY TABLESPACE temp
  ACCOUNT UNLOCK;

GRANT CONNECT TO app_user_ro;



--rols d'accs read-write i read-only

CREATE ROLE schema_rw_role;
CREATE ROLE schema_ro_role;

GRANT schema_rw_role TO app_user_rw;
GRANT schema_ro_role TO app_user_ro;

ALTER USER app_user_rw DEFAULT ROLE schema_rw_role;
ALTER USER app_user_ro DEFAULT ROLE schema_ro_role;


--default schema 

CREATE OR REPLACE TRIGGER app_user_rw.after_logon_trg
AFTER LOGON ON app_user_rw.SCHEMA
BEGIN
  DBMS_APPLICATION_INFO.set_module(USER, 'Initialized');
  EXECUTE IMMEDIATE 'ALTER SESSION SET current_schema=MANTENIMENT';
END;
/

CREATE OR REPLACE TRIGGER app_user_ro.after_logon_trg
AFTER LOGON ON app_user_ro.SCHEMA
BEGIN
  DBMS_APPLICATION_INFO.set_module(USER, 'Initialized');
  EXECUTE IMMEDIATE 'ALTER SESSION SET current_schema=MANTENIMENT';
END;
/


--otorgar privilegis de lectura i escriptura a schema_rw_role sobre les taules

set serveroutput on;
set serveroutput on size 1000000;

DECLARE
vcount1 number := 0;
vcount2 number := 0;
v_tablename varchar2(32);
vschema varchar2(30) := 'manteniment';
vrole varchar2(30) := 'schema_rw_role';

BEGIN

vschema := UPPER(vschema);
vrole := UPPER(vrole);

for ctable in ( select owner, table_name from dba_tables where owner like vschema )
loop
vcount1:= vcount1+1;
v_tablename := ctable.table_name;
begin
dbms_output.put_line(ctable.owner||'."'||ctable.table_name||'"');
execute immediate 'grant select,update, insert,delete on "'||ctable.owner||'"."'||ctable.table_name||'" to '||vrole;
EXCEPTION -- exception handlers begin
WHEN OTHERS THEN -- handles all other errors
dbms_output.put_line('err_num: '||SQLCODE);
dbms_output.put_line('err_msg: '||SUBSTR(SQLERRM, 1, 100));
dbms_output.put_line('table_name: '||v_tablename);
vcount1:= vcount1-1;
END;
end loop;

dbms_output.put_line('-- ');
dbms_output.put_line('Counter Tables is: '||vcount1);
dbms_output.put_line('-- ');

END;
/



--otorgar privilegis de lectura a app_role_ro  sobre les taules

set serveroutput on;
set serveroutput on size 1000000;

DECLARE
vcount1 number := 0;
vcount2 number := 0;
v_tablename varchar2(32);
vschema varchar2(30) := 'manteniment';
vrole varchar2(30) := 'schema_ro_role';
--vprivilege varchar2(30) := '&privilege';

BEGIN

vschema := UPPER(vschema);
vrole := UPPER(vrole);

for ctable in ( select owner, table_name from dba_tables where owner like vschema )
loop
vcount1:= vcount1+1;
v_tablename := ctable.table_name;
begin
dbms_output.put_line(ctable.owner||'."'||ctable.table_name||'"');
execute immediate 'grant select on "'||ctable.owner||'"."'||ctable.table_name||'" to '||vrole;
EXCEPTION -- exception handlers begin
WHEN OTHERS THEN -- handles all other errors
dbms_output.put_line('err_num: '||SQLCODE);
dbms_output.put_line('err_msg: '||SUBSTR(SQLERRM, 1, 100));
dbms_output.put_line('table_name: '||v_tablename);
vcount1:= vcount1-1;
END;
end loop;

dbms_output.put_line('-- ');
dbms_output.put_line('Counter Tables is: '||vcount1);
dbms_output.put_line('-- ');

END;
/


-- otorgar permisos d'exececuci de procediments i funcions a schema_rw_role

set serveroutput on;
set serveroutput on size 1000000;

DECLARE
vcount1 number := 0;
vcount2 number := 0;
v_objectname varchar2(32);
vschema varchar2(30) := 'manteniment';
vrole varchar2(30) := 'schema_rw_role';
--vprivilege varchar2(30) := '&privilege';

BEGIN

vschema := UPPER(vschema);
vrole := UPPER(vrole);

for cobject in (select owner, object_name from dba_procedures where owner like vschema )
loop
vcount1:= vcount1+1;
v_objectname := cobject.object_name;
begin
dbms_output.put_line(cobject.owner||'."'||cobject.object_name||'"');
execute immediate 'grant execute on "'||cobject.owner||'"."'||cobject.object_name||'" to '||vrole;
EXCEPTION -- exception handlers begin
WHEN OTHERS THEN -- handles all other errors
dbms_output.put_line('err_num: '||SQLCODE);
dbms_output.put_line('err_msg: '||SUBSTR(SQLERRM, 1, 100));
dbms_output.put_line('object_name: '||v_objectname);
vcount1:= vcount1-1;
END;
end loop;

dbms_output.put_line('-- ');
dbms_output.put_line('Counter objects is: '||vcount1);
dbms_output.put_line('-- ');

END;
/



-- otorgar permisos d'execuci de procediments i funcions de consulta a schema_ro_role

set serveroutput on;
set serveroutput on size 1000000;

DECLARE
vcount1 number := 0;
vcount2 number := 0;
v_objectname varchar2(32);
vschema varchar2(30) := 'manteniment';
vrole varchar2(30) := 'schema_ro_role';
--vprivilege varchar2(30) := '&privilege';

BEGIN

vschema := UPPER(vschema);
vrole := UPPER(vrole);

for cobject in (select owner, object_name from dba_procedures where owner like vschema and object_name like '%consulta%')
loop
vcount1:= vcount1+1;
v_objectname := cobject.object_name;
begin
dbms_output.put_line(cobject.owner||'."'||cobject.object_name||'"');
execute immediate 'grant execute on "'||cobject.owner||'"."'||cobject.object_name||'" to '||vrole;
EXCEPTION -- exception handlers begin
WHEN OTHERS THEN -- handles all other errors
dbms_output.put_line('err_num: '||SQLCODE);
dbms_output.put_line('err_msg: '||SUBSTR(SQLERRM, 1, 100));
dbms_output.put_line('object_name: '||v_objectname);
vcount1:= vcount1-1;
END;
end loop;

dbms_output.put_line('-- ');
dbms_output.put_line('Counter objects is: '||vcount1);
dbms_output.put_line('-- ');

END;
/

-- otorgar permisos al paquet MANTENIMENT."consultes_cursors"

GRANT EXECUTE ON MANTENIMENT."consultes_cursors" TO SCHEMA_RW_ROLE;
GRANT EXECUTE ON MANTENIMENT."consultes_cursors" TO SCHEMA_RO_ROLE;